summaryrefslogtreecommitdiff
path: root/lib/manifest.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/manifest.h')
-rw-r--r--lib/manifest.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/lib/manifest.h b/lib/manifest.h
index 8081479d8..6a331ee67 100644
--- a/lib/manifest.h
+++ b/lib/manifest.h
@@ -24,11 +24,12 @@ char * rpmPermsString(int mode)
/**
* Read manifest, glob items, and append to existing args.
* @param fd manifest file handle
* @retval argcPtr no. of args
* @retval argvPtr args themselves
*/
-int rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
+rpmRC rpmReadPackageManifest(FD_t fd, int * argcPtr, const char *** argvPtr)
/*@globals fileSystem, internalState @*/
/*@modifies fd, *argcPtr, *argvPtr, fileSystem, internalState @*/;
@@ -24,11 +24,12 @@ char * rpmPermsString(int mode)
/**
* Read manifest, glob items, and append to existing args.
- * @param fd manifest file handle
- * @retval argcPtr no. of args
- * @retval argvPtr args themselves
+ * @param fd manifest file handle
+ * @retval argcPtr no. of args
+ * @retval argvPtr args themselves
+ * @return RPMRC_OK on success
*/